@@ -16,9 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import gtk
-import consts
-import os.path
+import consts, gtk, os.path
 
 from gettext import gettext as _
 
@@ -42,8 +40,9 @@ def show(parent) :
         'Ingelrest François <Athropos@gmail.com>',
         '',
         _('Thanks to:'),
-        'Piotr Ozarowski',
-        'Ludovic Biancotto',
+        ' * Piotr Ozarowski',
+        ' * Ludovic Biancotto',
+        ' * Rob Neild',
     ])
 
     # Set logo
