@@ -16,9 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import os
-import gtk
-import consts
+import consts, gtk, os
 
 from gettext import gettext as _
 
