@@ -16,12 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import os
-import gtk
-import vte
-import sys
-import consts
-import prefsManager
+import consts, gtk, prefsManager, signal, sys, os, vte
 
 from gettext import gettext as _
 
@@ -48,7 +43,8 @@ def createDlg(parent) :
     wTree.signal_connect('onResponse',  onResponse)
     wTree.signal_connect('onDlgDelete', onDlgDelete)
     wTree.signal_connect('onDlgResize', onDlgResize)
-    wTree.signal_connect('onBtnStop',   lambda widget : os.kill(processPID, 9))
+    wTree.signal_connect('onBtnPause',  onBtnPause)
+    wTree.signal_connect('onBtnStop',   lambda widget : os.kill(processPID, signal.SIGKILL))
     # Configure the (scrollable) VTE
     wTree.get_widget('vteOutput').show_all()
     wTree.get_widget('vteOutput').connect('child-exited', onVTEChildExited)
@@ -59,14 +55,21 @@ def show(parent, cmd, args) :
     """
         Display this dialog and immediately launch cmd
     """
-    global processPID
+    global processPID, processPaused
 
     if dlg is None :
         createDlg(parent)
+
     wTree.get_widget('btnClose').set_sensitive(False)
     wTree.get_widget('btnStop').set_sensitive(True)
+    wTree.get_widget('btnPause').set_sensitive(True)
     wTree.get_widget('vteOutput').reset(True, True)
-    processPID = wTree.get_widget('vteOutput').fork_command(cmd, args)
+    wTree.get_widget('btnPause').set_label(_('Pause'))
+    wTree.get_widget('btnPause').set_image(gtk.image_new_from_stock(gtk.STOCK_MEDIA_PAUSE, gtk.ICON_SIZE_BUTTON))
+
+    processPaused = False
+    processPID    = wTree.get_widget('vteOutput').fork_command(cmd, args)
+
     dlg.show()
 
 
@@ -96,6 +99,7 @@ def onVTEChildExited(terminal) :
     processPID = -1
     wTree.get_widget('btnClose').set_sensitive(True)
     wTree.get_widget('btnStop').set_sensitive(False)
+    wTree.get_widget('btnPause').set_sensitive(False)
 
 
 def onDlgResize(dialog, rectangle) :
@@ -129,12 +133,32 @@ def onResponse(dialog, response, *args) :
         else :
             dlg.hide()
 
+
+def onBtnPause(widget) :
+    """
+        Pause or resume the process, if any
+    """
+    global processPaused
+
+    if processPaused :
+        processPaused = False
+        os.kill(processPID, signal.SIGCONT)
+        wTree.get_widget('btnPause').set_label(_('Pause'))
+        wTree.get_widget('btnPause').set_image(gtk.image_new_from_stock(gtk.STOCK_MEDIA_PAUSE, gtk.ICON_SIZE_BUTTON))
+    else :
+        processPaused = True
+        os.kill(processPID, signal.SIGSTOP)
+        wTree.get_widget('btnPause').set_label(_('Resume'))
+        wTree.get_widget('btnPause').set_image(gtk.image_new_from_stock(gtk.STOCK_MEDIA_PLAY, gtk.ICON_SIZE_BUTTON))
+
+
 #==========================================================
 #
 # Entry point
 #
 #==========================================================
 
-dlg        = None
-processPID = -1
-standAlone = False
+dlg           = None
+processPID    = -1
+standAlone    = False
+processPaused = False
