@@ -17,17 +17,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import sys
-import gtk
-import consts
-import locale
-import os.path
-import gettext
-import dlgAbout
-import dlgOutput
-import treeview
-import gtk.glade
-import prefsManager
+import consts, dlgAbout, dlgOutput, gettext, gtk, gtk.glade, locale, os.path, prefsManager, sys, treeview
+
 
 #==========================================================
 #
@@ -180,9 +171,8 @@ gtk.glade.bindtextdomain(consts.appNameShort, consts.dirLocale)
 checkActions = {'radActionRepair' : 'r', 'radActionVerify' : 'v'}
 
 # Check whether a .par2 file was specified on the command line
-if len(sys.argv) > 1 :
+if len(sys.argv) == 2 and sys.argv[1].lower().endswith('.par2') :
     dlgOutput.run('par2', ['par2', checkActions[prefsManager.get('grpAction')]] + getAdvancedSettings(False) + ['--', sys.argv[1]])
-    prefsManager.save()
     sys.exit()
 
 # Widgets which state is saved and restored
@@ -215,6 +205,7 @@ wTree.signal_connect('onRadioButton',         onRadioButton)
 wTree.signal_connect('onCheckBox',            onCheckBox)
 wTree.signal_connect('onTreeviewKey',         treeview.onKey)
 wTree.signal_connect('onTreeviewMouseButton', treeview.onMouseButton)
+wTree.signal_connect('onTreeviewDragDrop',    treeview.onDragDrop)
 wTree.signal_connect('onMnuAbout',            lambda widget : dlgAbout.show(window))
 wTree.signal_connect('onSpinButton',          lambda spin : prefsManager.set(spin.get_name(), int(spin.get_value())))
 
@@ -225,7 +216,16 @@ filter.add_pattern('*.PAR2')
 wTree.get_widget('fcOpenPar2').set_filter(filter)
 wTree.get_widget('fcOpenPar2').set_current_folder(consts.dirUsr)
 
-# Prepare widgets and show the window
+# Add specified files, if any, to the tree
+if len(sys.argv) > 1 :
+    for path in map(os.path.abspath, sys.argv[1:]) :
+        if os.path.isfile(path) :
+            treeview.addFile(path)
+        elif os.path.isdir(path) :
+            treeview.addDirectoryContent(path)
+    wTree.get_widget('nbkMain').set_current_page(prefsManager.PAGE_CREATE)
+
+# Here we go
 prefsToWidgets()
 window.show()
 gtk.main()
