@@ -16,11 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import os
-import consts
-import typeToolBox
-import xml.dom.ext
-import xml.dom.minidom
+import consts, os, typeToolBox, xml.dom.ext, xml.dom.minidom
 
 from gettext import gettext as _
 
