@@ -16,25 +16,27 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
+from gettext import gettext as _
+
 # Supported types
 # 'bool' type must be placed *before* 'int' type, otherwise booleans are detected as integers
 types = {bool : 'bool', int : 'int', str : 'str'}
 
+
 # Return a String with the type of value
 def getType(value) :
     for type in types.keys() :
         if isinstance(value, type) :
             return types[type]
-    raise TypeError, str(value) + ' has an unsupported type'
+    raise TypeError, str(value) + _(' has an unsupported type')
+
 
 # Return value, casted into type
 def cast(value, type) :
     if type == 'bool' :
-        if value == 'True' :
-            return True
-        return False
+        return value == 'True'
     elif type == 'int' :
         return int(value)
     elif type == 'str' :
         return str(value)
-    raise TypeError, type + ' is an unsupported type'
+    raise TypeError, type + _(' is an unsupported type')
